#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

NAMESPACE="uipath-infra"
CONFIG_NAME="service-cluster-configurations"

function update_cluster_config() {
  local key=$1
  local value=$2

  kubectl get namespace "${NAMESPACE}" &> /dev/null \
    || kubectl create namespace "${NAMESPACE}" &> /dev/null \
    || error "Failed to create namespace \"${NAMESPACE}\""

  configmap=$(kubectl get secret $CONFIG_NAME \
              --namespace $NAMESPACE \
              -o json \
              --ignore-not-found 2>/dev/null)

  if [[ -z $configmap ]];
  then
    kubectl create secret generic $CONFIG_NAME \
      --from-literal="${key^^}"="$value" \
      --namespace $NAMESPACE &> /dev/null
  else
    value=$(base64 <<<"$value")
    echo "${configmap}" \
    | jq ".data += { \"${key^^}\": \"$value\" }" \
    | kubectl apply -f - &> /dev/null
  fi

  kubectl label secret $CONFIG_NAME config-discovery=yes \
    --namespace $NAMESPACE --overwrite &> /dev/null
}

function get_cluster_config() {
  local key=$1
  
  # the go template if prevents it from printing <no-value> instead of empty strings
  value=$(kubectl get secret ${CONFIG_NAME} \
    -o "go-template={{if index .data \"${key^^}\"}}{{index .data \"${key^^}\"}}{{end}}" \
    -n ${NAMESPACE} --ignore-not-found 2>/dev/null) || true

  echo -n "$(base64 -d <<<"$value")"
}

function get_cluster_config_default() {
  value="$(get_cluster_config "$1")"

  [[ -z ${value} ]] && value=$2
  
  echo -n "$value"
}
