#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

function check_package_installed() {
    rpm -q "$1" &>/dev/null && return 0 || return 1
}

# Removes entry for rke2-* under exclude in given .conf file in first param
function remove_rke2_entry_from_exclude() {
  local current_exclude_list new_exclude_list
  YUM_CONF_FILE=$1
  if [[ ! -s "${YUM_CONF_FILE}" ]];
  then
    # File is empty
    return
  fi
  current_exclude_list=$(grep 'exclude=' "${YUM_CONF_FILE}" | tail -1)
  if echo "$current_exclude_list" | grep -q 'rke2-*';
  then
    if [[ -w ${YUM_CONF_FILE} ]];
    then
      new_exclude_list=$(printf '%s\n' "${current_exclude_list//rke2-* /}")
      new_exclude_list=$(printf '%s\n' "${new_exclude_list//rke2-*,/}")
      new_exclude_list=$(printf '%s\n' "${new_exclude_list//rke2-\*/}")
      sed -i "/exclude=.*rke2-\*/d" "${YUM_CONF_FILE}"
      echo "${new_exclude_list}" >> "${YUM_CONF_FILE}"
    else
      error "${YUM_CONF_FILE} file is readonly and contains rke2-* under package exclusion. Please remove the entry for AS to work."
    fi
  fi
}

function enable_rke2_package_upgrade() {
  remove_rke2_entry_from_exclude /etc/dnf/dnf.conf
  remove_rke2_entry_from_exclude /etc/yum.conf
}

# Adds entry for rke2-* under exclude in given .conf file in first param
function add_rke2_entry_in_exclude() {
  local current_exclude_list new_exclude_list
  YUM_CONF_FILE=$1
  if [[ ! -s "${YUM_CONF_FILE}" ]];
  then
    #File is empty
    return
  fi
  if [[ ! -w "${YUM_CONF_FILE}" ]];
  then
    error "${YUM_CONF_FILE} file is readonly. Please exclude rke2-* from yum install/upgrade, so that these packages do not get updated outside of AS installer."
  fi
  current_exclude_list=$(grep 'exclude=' "${YUM_CONF_FILE}" | tail -1)
  if [[ -n ${current_exclude_list} ]];
  then
    if ! echo "$current_exclude_list" | grep -q 'rke2-*';
    then
      current_exclude_list=$(echo "${current_exclude_list}" | xargs)
      new_exclude_list=$(printf '%s rke2-*\n' "${current_exclude_list}")
      sed -i "/exclude=.*/d" "${YUM_CONF_FILE}"
      echo "${new_exclude_list}" >> "${YUM_CONF_FILE}"
    fi
  else
    echo "exclude=rke2-*" >> "${YUM_CONF_FILE}"
  fi
}

function disable_rke2_package_upgrade() {
  add_rke2_entry_in_exclude /etc/dnf/dnf.conf
  add_rke2_entry_in_exclude /etc/yum.conf
}
