#!/bin/bash

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)

if [[ -z "${SCRIPT_DIR}" ]]; then
    echo "Script dir not present"
    exit 1
fi

#shellcheck disable=SC1090,SC1091
source "${SCRIPT_DIR}/utils.sh"
export KUBECONFIG=/etc/rancher/rke2/rke2.yaml PATH=$PATH:/var/lib/rancher/rke2/bin

function mongo_credentials() {
  USER_NAME=$(kubectl -n mongodb get secret mongo-admin-user -o json | jq -r '.data.USER_NAME' | base64 -d )
  PASSWORD=$(kubectl -n mongodb get secret mongo-admin-user -o json | jq -r '.data.PASSWORD' | base64 -d )
}

function test_mongo_highLatency_alert() {
    change_sync_policy "none"
    modify_mongo_alert_config
    [[ "$(is_alert_fired "MongodbHighLatency" "" "")" == "true" ]] && appendOutput "1888926" "true" || appendOutput "1888926" "false"
     change_sync_policy "automated"
 }
 function test_mongo_cert_alert() {
    change_sync_policy "none"
    modify_alert_config
    [[ "$(is_alert_fired "MongodbCertExpiration" "" "")" == "true" ]] && appendOutput "1888849" "true" || appendOutput "1888849" "false"    
    change_sync_policy "automated"
 }
function modify_alert_config() {
    kubectl get prometheusrule uipath-apps-mongodb-alerts -n mongodb -o json | jq '(.spec.groups[0].rules[] | select(.alert == "MongodbCertExpiration") | .expr) |= "(floor(avg(mongodb_ss_security_SSLServerCertificateExpirationDate - mongodb_date)/(86400000) \u003c 365))"' | kubectl replace -f -
    kubectl get prometheusrule uipath-apps-mongodb-alerts -n mongodb -o json | jq '(.spec.groups[0].rules[] | select(.alert == "MongodbCertExpiration") | .for) |= "0m"' | kubectl replace -f -
}
function modify_mongo_alert_config() {
    kubectl get prometheusrule uipath-apps-mongodb-alerts -n mongodb -o json | jq '(.spec.groups[0].rules[] | select(.alert == "MongodbHighLatency") | .expr) |= "rate(mongodb_mongod_op_latencies_latency_total[5m]) / rate(mongodb_mongod_op_latencies_ops_total[5m]) \u003c 250000"' | kubectl replace -f -
    kubectl get prometheusrule uipath-apps-mongodb-alerts -n mongodb -o json | jq '(.spec.groups[0].rules[] | select(.alert == "MongodbHighLatency") | .for) |= "0m"' | kubectl replace -f -
}
function change_sync_policy() {
  /opt/UiPathAutomationSuite/UiPath_Installer/bin/argocd app set fabric-configure --sync-policy "$1"
  /opt/UiPathAutomationSuite/UiPath_Installer/bin/argocd app set rancher-monitoring --sync-policy "$1"  
}
